/* i2c-workaround.h - a collection of kernel defines needed for I2C
 * Copyright (C) 2005 Georg Lukas <georg@boerde.de>
 * (This Program is under the GNU General Public License)
 * 
 * Original copyright by:
 *	Kysti Mlkki <kmalkki@cc.hut.fi>
 *	Frodo Looijaard <frodol@dds.nl>
 *	Simon G. Vogl
 *	the linux kernel maintainer team
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <inttypes.h>

/* 
 * Data for SMBus Messages 
 */
#define I2C_SMBUS_BLOCK_MAX     32      /* As specified in SMBus standard */    
#define I2C_SMBUS_I2C_BLOCK_MAX 32      /* Not specified but we use same structure */
union i2c_smbus_data {
        uint8_t byte;
        uint16_t word;
        uint8_t block[I2C_SMBUS_BLOCK_MAX + 3]; /* block[0] is used for length */
                          /* one more for read length in block process call */
                                                    /* and one more for PEC */
};

#define I2C_SLAVE       0x0703  /* Change slave address                 */
#define I2C_SMBUS_READ  1
#define I2C_SMBUS_WRITE 0

/* SMBus transaction types (size parameter in the above functions) 
   Note: these no longer correspond to the (arbitrary) PIIX4 internal codes! */
#define I2C_SMBUS_QUICK             0
#define I2C_SMBUS_BYTE              1
#define I2C_SMBUS_BYTE_DATA         2 
#define I2C_SMBUS_WORD_DATA         3
#define I2C_SMBUS_PROC_CALL         4
#define I2C_SMBUS_BLOCK_DATA        5
#define I2C_SMBUS_I2C_BLOCK_DATA    6
#define I2C_SMBUS_BLOCK_PROC_CALL   7           /* SMBus 2.0 */
#define I2C_SMBUS_BLOCK_DATA_PEC    8           /* SMBus 2.0 */
#define I2C_SMBUS_PROC_CALL_PEC     9           /* SMBus 2.0 */
#define I2C_SMBUS_BLOCK_PROC_CALL_PEC  10       /* SMBus 2.0 */
#define I2C_SMBUS_WORD_DATA_PEC    11           /* SMBus 2.0 */

#define I2C_SMBUS       0x0720  /* SMBus-level access */

